/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

var app = {
    
    // Application Constructor
    initialize: function() {
        this.bindEvents();
    },
    
    
    // Bind Event Listeners
    //
    // Bind any events that are required on startup. Common events are:
    // 'load', 'deviceready', 'offline', and 'online'.
    bindEvents: function() {
        // 23/04/2014
        document.addEventListener("deviceready", this.onDeviceReady, false);
        
        // executado quando o dispositivo esta conectado à internet
        document.addEventListener("online", this.onLine, false);
        
        // executado quando o dispositivo esta desconectado da internet
        document.addEventListener("offline", this.offLine, false);

        // executado quando pressiona o botão de voltar
        document.addEventListener("menubutton", this.menuButton, false);
        
        // executado quando pressiona o botão de voltar
        document.addEventListener("backbutton", this.backButton, false);
        
        // este evento é disparado quando um aplicativo é recuperado do fundo
        document.addEventListener("resume", this.resume, false);

        // este evento é disparado quando um aplicativo é colocado em segundo plano
        document.addEventListener("pause", this.pause, false);
        
        // se não for mobile, chama mesmo assim!
        if (!app.isMobile) {
            this.onDeviceReady();
        }
    },


    // deviceready Event Handler
    //
    // The scope of 'this' is the event. In order to call the 'receivedEvent'
    // function, we must explicity call 'app.receivedEvent(...);'
    onDeviceReady: function() {
        //app.receivedEvent('deviceready');
        
        // http://www.igorcosta.com/apache-cordova-removendo-os-300ms-de-delay-entre-o-toque-e-o-click
        FastClick.attach(document.body);
        

        // device.platform: Android
        // device.version: 4.2.1
        // device.uuid: e04de5e5797e84bc
        // device.cordova: 3.4.0
        // device.model: JK809
        if (app.isMobile) {
            app.device = device;
        }

        try {

            /*require([
                'app/tmz.js', 
                'app/tmz.ComboBox.js', 
                'app/base.js', 
                'app/listaPacotes.js',
                'app/listaDetalhesPacote.js',
                'app/dadosPacote.js',
                'app/cadastrarPacotePorVoz.js',
                'app/login.js',
                'app/alterarSenha.js',
                'app/localizarPacote.js',
                'app/background.js',
                'app/service.js',
                'app/pushNotification.js',
                'app/notificacoes.js',
                'app/mobile.js',
            ], 
            function() {*/
                
                RastreadorPacotes.Login.Init();
                RastreadorPacotes.CadastrarUsuario.Init();
                RastreadorPacotes.RecuperarSenha.Init();
                RastreadorPacotes.Detalhes.Init();
                RastreadorPacotes.Principal.Init();
                RastreadorPacotes.CadatrarPacotePorVoz.Init();
                RastreadorPacotes.AlterarSenha.Init();
                RastreadorPacotes.DadosPacote.Init();
                RastreadorPacotes.LocalizarPacote.Init();
                RastreadorPacotes.Notificacoes.Init();
                
                // verifica se o usuário já esta logado
                var user = localStorage.getItem("user");
    
                // se existir o objeto de usuário...
                if (user != null) {
                    $$("#emptyListaPacotes").show();
    
                    Lungo.Router.section("telaPrincipal");
                    RastreadorPacotes.Principal.AtualizarLista(true);
                    
                    if (app.isMobile) {
                        MyPushNotification.Registrar();
                    }
    
                } else {
                    Lungo.Router.section("telaLogin");
                }
    

                /*
                OPA
                if (app.isMobile) {
                    MyBackgroundService.Init();
                }
                */
    
            //});

        } catch(err) {
            MyMobile.Alert("Erro", err, "Ok");
        }
    },



    /**
     * @descrição: Método executado quando o botão de VOLTAR do celular é pressionado
     **/
    backButton: function() {
        // pega o histórico
        var historico = Lungo.Router.history();

        if (historico == null) {
            return;
        }

        switch (historico.toLowerCase()) {
            case "telalogin": {
                
                MyMobile.ExitApp();
                break;
            }
            
            
            case "telaprincipal": {
                

                // verifica se o footer esta visível
                // se não possuir o class 'hidden', significa que o footer esta visível
                if (!$$("#telaPrincipal footer").hasClass("hidden")) {
                    $$("#telaPrincipal footer").addClass("hidden");
                    
                    // oculta todos os checkbox de exclusão
                    $$("#telaPrincipal .liActionRight").hide();

                    return;
                }
                
                // se esta na tela principal, verifica se o seu menu esta visível
                var menuAberto = $$("#menuOpcoesPrincipal").hasClass("show");
                RastreadorPacotes.Principal.menuAberto = menuAberto;
    
                if (menuAberto) {
                    // oculta o menu de opções
                    RastreadorPacotes.Principal.abrirDetalhes = false;
                    Lungo.Aside.toggle();
                    
                    return;
                }
                
                
                MyMobile.ExitApp();
                break;
            }
            
            case "teladetalhespacote": {

                // se esta na tela de detalhes do pacote, verifica se o seu menu esta visível
                var menuAberto = $$("#menuOpcoesDetalhesPacote").hasClass("show");
                RastreadorPacotes.Detalhes.MenuAberto = menuAberto;
    
                if (menuAberto) {
                    // oculta o menu de opções
                    RastreadorPacotes.Detalhes.AbrirDetalhes = false;
                    Lungo.Aside.toggle();

                    return;
                }

                Lungo.Router.back();
                break;
            }
            
            default: {
                Lungo.Router.back();
            }
        }
    },
    
    
    /*gravarLog: function(texto) {
        
        if (!app.isMobile) {
            return;
        }

        try {
            window.requestFileSystem(
                LocalFileSystem.PERSISTENT, 
                0, 
                function(fileSystem) {
                    
                    fileSystem.root.getDirectory(
                        "/storage/sdcard0/RastreadorPacotes",
                        {
                            create: true, 
                            exclusive: false
                        },
                        function(directory) {


                            try {
                                fileSystem.root.getFile("/storage/sdcard0/RastreadorPacotes/log.txt", 
                                    {
                                        create: true, 
                                        exclusive: false
                                    }, 
                                    function(fileEntry) {
                                        try {
                                            fileEntry.createWriter(
                                                function(fileWriter) {
                                                    try {
                        
                                                        fileWriter.onwriteend = function(e) {
                                                            console.log('Write completed.');
                                                        };
                                                        
                                                        fileWriter.onerror = function(e) {
                                                            console.log('Write failed: ' + e.toString());
                                                        };
                        
                                                        fileWriter.seek(fileWriter.length);
                                                        fileWriter.write(tmz.Convert.dateToString(new Date()) + " - " + texto + "\r\n");
                                                    } catch(err) {
                                                        FileSystemError(err);
                                                    }
                                                },
                                                FileSystemError
                                            );
                                        } catch(err) {
                                            FileSystemError(err);
                                        }
                                    }, 
                                    FileSystemError
                                );
                            } catch(err) {
                                FileSystemError(err);
                            }


                        }
                    );

                },
                FileSystemError
            );
        } catch(err) {
            //alert(err);
        }
    },*/


    /**
     * @descrição: Método executado quando o botão de MENU do celular é pressionado
     **/
    menuButton: function() {
        
    },


    /**
     * @descrição: Método disparado automaticamente quando uma conexão com a internet é detectada
     **/
    onLine: function() {
        app.isOnline = true;
        
        if (Lungo.Router.history() == "telaPrincipal") {
            $$("#emptySemConexaoListaPacotes").hide();

            if ((RastreadorPacotes.lista == null) || (RastreadorPacotes.lista.lenght == 0)) {
                $$("#emptyListaPacotes").show();
                return;
            }
        }

        $$("#" + Lungo.Router.history() + " .avisoSemConexao")
            .css("visibility", "hidden")
            .css("opacity", "0")
            .css("z-index", "-1");
    },


    /**
     * @descrição: Método disparado automaticamente quando a conexão com a internet cai
     **/
    offLine: function() {
        app.isOnline = false;
        
        if (Lungo.Router.history() == "telaPrincipal") {
            if ((RastreadorPacotes.lista == null) || (RastreadorPacotes.lista.lenght == 0)) {
                $$("#emptyListaPacotes").hide();
                $$("#emptySemConexaoListaPacotes").show();
                return;
            }
        }
        
        $$("#" + Lungo.Router.history() + " .avisoSemConexao")
            .css("visibility", "visible")
            .css("opacity", "1")
            .css("z-index", "100");
    },
    
    
    pause: function() {
        //app.gravarLog("APP PAUSE");
    },

    
    resume: function() {
        //app.gravarLog("APP RESUME");
    }

    // Update DOM on a Received Event
    /*receivedEvent: function(id) {
        var parentElement = document.getElementById(id),
            listeningElement = parentElement.querySelector('.listening'),
            receivedElement = parentElement.querySelector('.received');

        listeningElement.setAttribute('style', 'display:none;');
        receivedElement.setAttribute('style', 'display:block;');

        console.log(app.namespace + " - Received Event: " + id);
    }*/
};



var env = Lungo.Core.environment(),
    appTimeClickExit = false,
    timerClickExit1 = 0,
    timerClickExit2 = 0;

// importante inicializar, já que nesta versão do aplicativo não é possível realizar a ordenação
// desta forma este localStorage 'sort' não existirá
var search = {
    by: "DataUltimaPosicao",
    order: "DESC",
    type: "datetime"
};

// grava a ordenação
localStorage.setItem("sort", JSON.stringify(search));


// adiciona configurações do projeto ao app
app.config = {
    versao: "2.0.3",
    namespace: "tmz.rastreador",
    sistema: "androidfree",
    nome: "Rastreador de Pacotes",
    server: "http://rp.rastreadordepacotes.com.br/wsindex.php?a={0}",
    local: "producao" // producao
};
app.isMobile = env.isMobile;
app.isOnline = true;
app.producao = true;


// seta a configuração do APP na interface 
$$("#sobreApp").html("versão: " + app.config.versao);


app.initialize();


Lungo.Config.nome = app.config.nome;
Lungo.Config.versao = app.config.versao;
Lungo.Config.history = false;


// env.os.name
// env.os.version


/*
Lungo.Resource.load([
    "views/cadastrarUsuario.html",
    "views/gerarNovaSenha.html"
]);

function FileSystemError(error) {
    //writer.onwriteend = function(evt) {};
    //writer.write(error.code);
    alert(error);
    alert(error.code);
}*/