var rpBackground = {};

(function() {
    "use strict";


    // função para buscar a lista de pacotes
    // apenas busca a lista, NÃO realiza o rastreio
    rpBackground.getLista = function() {
        var data = RastreadorPacotes.StrAcessoWebService();
        if (data == null) {
            return;
        }

        data.rastrear = "0";
        
        //app.gravarLog("background: start getLista");
        console.debug("background: start getLista");
    
        $$.post(
            app.config.server.format("PacoteGetLista"),
            data,
            function(retorno) { 
                
                //app.gravarLog("background: end getLista");
                console.debug("background: end getLista");
    
                if (!retorno.success) {
                    return;
                }

                // indica a data/hora do último update
                localStorage.setItem("lastUpdate", tmz.Convert.dateToString(new Date()));

                // vai criar a lista
                RastreadorPacotes.Principal.CriarLista(retorno.rows, true);
                
                // se houver algum registro, vai processar para buscar novas posições
                if (retorno.total > 0) {
                    rpBackground.processarGetNovasPosicoes(retorno.rows, 0);
                }
            }
        );
    };
    
    

    rpBackground.processarGetNovasPosicoes = function(listaAtual, ultimoIndice) {
        //var listaAtual = JSON.parse(localStorage.getItem("list"));
        
        if ((listaAtual == null) || (listaAtual.length == 0)) {
            return;
        }
        
        var MAX_PACOTES_AGRUPADOS = 3,
            MAX_MINUTOS = 15,
            dataAtual = new Date(),
            id = "",
            count = 0;
        
        ultimoIndice = ultimoIndice || 0;
    
        for (var i = ultimoIndice; i < listaAtual.length; i++) {
            if (listaAtual[i].Status.toLowerCase() == "entregue") {
                ultimoIndice = i;
                continue;
            }
            
            // verifica a diferença da data atual e a data da última atualização
            var dataAtualizacao = new Date(listaAtual[i].DataUltimaAtualizacao),
                diff = Math.round((dataAtual - dataAtualizacao)/1000) / 60;
            
            if (diff <= MAX_MINUTOS) {
                ultimoIndice = i;
                continue;
            }
            
            id += listaAtual[i].Id;
            if (i < (listaAtual.length - 1)) {
                id += ",";
            }
            
            count += 1;
            ultimoIndice = i;
    
            if (count == MAX_PACOTES_AGRUPADOS) {
                break;
            }
        }
        
        // se o último caractere foi uma VIRGULA...
        if (id.substr(id.length-1, 1) == ",") {
            id = id.substr(0,id.length-1);
        }
    
        if ((id == "") || (listaAtual.length == ultimoIndice)) {
            // vai criar a lista
            RastreadorPacotes.Principal.CriarLista(listaAtual, false);
            return;
        }
    
        // vai carregas as posições dos pacotes
        console.debug("start pacoteGetNovasPosicoes(" +id+ ")"); 
        rpBackground.pacoteGetNovasPosicoes(listaAtual, id, ultimoIndice);
    };
    
    
    /**
     * @descrição: Faz uma consulta ao servidor atrás de pacotes com novas posições
     **/
    rpBackground.pacoteGetNovasPosicoes = function(listaAtual, id, ultimoIndice) {
        if ((id == null) || (id == "")) {
            return;
        }


        var data = RastreadorPacotes.StrAcessoWebService();
        if (data == null) { 
            return; 
        }
        
        data.id = id;
        
        console.debug("background: start getNovasPosicoes (" + id + ")");
        
        $$.post(
            app.config.server.format("PacoteGetNovasPosicoes"),
            data,
            function(retorno) {
                
                console.debug("background: end getNovasPosicoes (" + id + ")");
                
                //var listaAtual = JSON.parse(localStorage.getItem("list"));
                
                if (retorno == null) {
                    // faz uma busca novamente com o mesmo indice
                    rpBackground.processarGetNovasPosicoes(listaAtual, ultimoIndice);
                    return;
                }
                
                
                // verifica se houve algum retorno
                // o retorno pode ser 0 se nenhum dos pacotes da iteração atual tiver sido movimentado
                if (retorno.totalRegistros == 0) {
                    rpBackground.processarGetNovasPosicoes(listaAtual, ultimoIndice+1);
                    return;
                }
                
                
                
                var idsMovimentados = "",
                    indice = -1;
                
                for (var i = 0, len = retorno.rows.length; i < len; i++) 
                {
                    var posicao = retorno.rows[i].Posicao;
                    if ((posicao == null) || (posicao.length == 0)) {
                        continue;
                    }
                    
                    // procura na listaAtual, um objeto com o atributo CodigoRastreio
                    // obtém o índice na listaAtual
                    indice = listaAtual.searchInObject("CodigoRastreio", retorno.rows[i].CodigoRastreio);
                    
                    if ((indice >= 0) && (listaAtual[indice].CodigoRastreio == retorno.rows[i].CodigoRastreio)) {
                        listaAtual[indice] = retorno.rows[i]; //.reverse();
                    }
                    
                    idsMovimentados += retorno.rows[i].Id;
    
                    if (i < (retorno.rows.length - 1)) {
                        idsMovimentados += ",";
                    }
                    
                    
                    MyMobile.EmitirNotificacao(
                        retorno.rows[i].Id,
                        retorno.rows[i].Descricao.substring(0, 100),
                        retorno.rows[i].Posicao[retorno.rows[i].Posicao.length - 1].Detalhes,
                        null
                    )
                }


                if (idsMovimentados != "") {
                    rpBackground.desativarNotificacoes(idsMovimentados);
                }

                rpBackground.processarGetNovasPosicoes(listaAtual, ultimoIndice+1);
            }
        );
        
    };

    
    /**
     * @descrição: Desativa as notificações mobile para os pacotes passados por parâmetro
     **/
    rpBackground.desativarNotificacoes = function(ids)
    {
        var data = RastreadorPacotes.StrAcessoWebService();
        if (data == null) {
            return; 
        }
        
        data.idsPacote = ids;
        
        console.debug("background: start desativarNotificacao (" + ids + ")");

        $$.post(
            app.config.server.format("PacoteDesativarNotificacao"),
            data,
            function(retorno) {
                console.debug("background: end desativarNotificacao (" + ids + ")");
            }
        );
    };

}());