var RastreadorPacotes = RastreadorPacotes || {};

RastreadorPacotes.CadatrarPacotePorVoz = function() {
    "use strict";
    
    
    var _articles = document.querySelectorAll("#telaCadastrarPacotePorVoz article");
    
    var _definirAcaoBotoes = function() {
        $$("#telaCadastrarPacotePorVoz [data-action=capturar]").tap(function() {
            RastreadorPacotes.CadatrarPacotePorVoz.Capturar();
        });
        
        $$("#telaCadastrarPacotePorVoz [data-action=voltar]").tap(function() {
            RastreadorPacotes.CadatrarPacotePorVoz.Voltar();
        });
        
        $$("#telaCadastrarPacotePorVoz [data-action=proximo]").tap(function() {
            RastreadorPacotes.CadatrarPacotePorVoz.Proximo();
        });
    };


    var _dados = {
        codigoRastreio: "",
        descricao: "",
        observacao: "",
        categoria: "",
        avisarTambem: ""
    };
    
    
    var _dom = {
        codigoRastreio: document.getElementById("txtVozCodigoRastreio"),
        descricao: document.getElementById("txtVozDescricaoPacote"),
        observacao: document.getElementById("txtVozObservacaoPacote"),
        categoria: document.getElementById("txtVozCategoriaPacote")
    };
    
    
    var _msg = [
        "Fale o código de rastreio",
        "Fale uma descrição para este pacote",
        "Fale uma observação para este pacote"
    ];
    

    return {
        
        paginaAtual: 0,
        articles: _articles,
        
        Init: function() {
            _definirAcaoBotoes();
        },


        Capturar: function() {

            // diz que quer apenas UM resultado
            // passa a mensagem
            // função de callback
            MyMobile.RecognizeSpeech(1, _msg[this.paginaAtual], function(resultado) {


                // verifica em qual página esta
                switch (RastreadorPacotes.CadatrarPacotePorVoz.paginaAtual) {
                    case 0: { // página CODIGO DE RASTREIO
                        // testa se o texto é um códido de rastreio válido
                        // exemplo: AA123456789BB
                        // DUAS LETRAS / NOVE NÚMEROS / DUAS LETRAS

                        resultado = resultado.toString().replaceAll(" ", "").toUpperCase();
                        //alert("-> " + resultado);
                            
                        if (resultado.match(/[A-Z]{2}\d{9}[A-Z]{2}/i)) {
                            _dom.codigoRastreio.value = resultado;
                            return;
                        }
                        
                        MyMobile.Alert(
                            "", 
                            "Desculpe, o texto informado (" + resultado + ") não é um código de rastreio válido. Fale pausadamente.",
                            "Ok"
                        );

                        break;
                    }
                    
                    case 1: { // página DESCRICAO
                        _dom.descricao.value = resultado;
                        break;
                    }
                    
                    case 2: { // página OBSERVACAO
                        _dom.observacao.value = resultado;
                        break;
                    }
                }
                

            });

        },
        
        
        Novo: function() {
            _dados.codigoRastreio = "";
            _dados.descricao = "";
            _dados.observacao = "";
            _dados.categoria = "";
            _dados.avisarTambem = "";
            
            // limpa todos os campos
            $$("#telaCadastrarPacotePorVoz input, #telaCadastrarPacotePorVoz textarea").each(
                function(item) { 
                    item.value = ""; 
                }
            );
        },
        
        
        Validar: function() {
            var article = this.articles[this.paginaAtual],
                mandatory = article.getAttribute("data-mandatory"),
                dataType = article.getAttribute("data-type");
             
            // verifica se é obrigatório   
            if ((mandatory == null) || (mandatory == "false")) {
                return true;
            }
            
            // verifica se informou o tipo do campo
            if (dataType == null) {
                return true;
            }
            
            // se o tipo for código de rastreio, faz a correta validação
            switch (dataType.toLowerCase()) {
                case "codigorastreio": {
                    var valCodigoRastreio = document.getElementById("txtVozCodigoRastreio").value.trim();
                    
                    if (valCodigoRastreio == "") {
                        MyMobile.Alert("", "Por favor, informe o código de rastreio.", "Ok");
                        return false;
                    }
                    
                    if (!RastreadorPacotes.ValidarCodigoRastreio(valCodigoRastreio)) {
                        MyMobile.Alert("", "Desculpe, o texto informado não é um código de rastreio válido.", "Ok");
                        return false;
                    } 
                    
                    // guarda o value
                    _dados.codigoRastreio = valCodigoRastreio.toUpperCase();
                    
                    break;
                }
                
                case "descricao": {
                    var valDescricao = document.getElementById("txtVozDescricaoPacote").value.trim();

                    if (valDescricao == "") {
                        MyMobile.Alert("", "Por favor, informe uma descrição para este pacote.", "Ok");
                        return false;
                    }
                    
                    _dados.descricao = valDescricao;
                    
                    break;
                }
            }
            
            return true;
        },


        Voltar: function() {
            
            // se for 0, sai fora...
            if (this.paginaAtual == 0) {
                this.paginaAtual = 0;

                Lungo.Router.back();
                return;
            }
            
            $$(this.articles[this.paginaAtual]).removeClass("active");
            $$(this.articles[this.paginaAtual - 1]).addClass("active");

            this.paginaAtual -= 1;
        },
        
        
        Proximo: function() {
            
            if (!this.Validar()) {
                return;
            }
            
            if (this.paginaAtual == (this.articles.length - 1)) {
                RastreadorPacotes.CadatrarPacotePorVoz.Salvar();
                return;
            }
            
            $$(this.articles[this.paginaAtual]).removeClass("active");
            $$(this.articles[this.paginaAtual + 1]).addClass("active");

            this.paginaAtual += 1;
        },
        
        
        Salvar: function() {
            if ((!app.isOnline) && (app.isMobile)) {
                MyMobile.Alert("", "Por favor, verifique a sua conexão com a internet e tente novamente.", "Ok");
                return;
            }
            
            var obj = RastreadorPacotes.GetPacotePeloCampo("CodigoRastreio",  _dom.codigoRastreio.value.trim()),
                inclusao = (obj == null),
                action = (inclusao) ? "PacoteIncluirPacote" : "PacoteAlterarDados",
                data = RastreadorPacotes.StrAcessoWebService();
                
            data.idPacote = (inclusao) ? 0 : obj.Id;
            data.idTransportadora = (inclusao) ? 1 : obj.IdTransportadora;
            data.favorito = (inclusao) ? false : obj.Favorito;
            data.formaInclusao = (inclusao) ? "Manual" : obj.FormaInclusao;
            data.servicoUtilizado = (inclusao) ? "Android" : obj.ServicoUtilizado;
            data.tipoCaixa = (inclusao) ? "Entrada" : obj.TipoCaixa;
            data.codigoRastreio = _dom.codigoRastreio.value.trim();
            data.descricao = _dom.descricao.value.trim();
            data.avisarTambem = (inclusao) ? "" : obj.AvisarTambem;
            data.observacao = _dom.observacao.value.trim();
            data.categoria = _dom.categoria.value.trim();
            
            if (!inclusao) {
                obj.CodigoRastreio = _dom.codigoRastreio.value.trim();
                obj.Descricao = _dom.descricao.value.trim();
                obj.Observacao = _dom.observacao.value.trim();
                obj.Categoria = _dom.categoria.value.trim();
            }
            

            RastreadorPacotes.SalvarPacote(action, inclusao, data, obj);
        }
    };
}();