var tmz = tmz || {};

tmz.ComboBox = function () {
    "use strict";

    /**
     * @descrição: retorna o elemento HTML baseado no parâmetro 'el'
     * @return: elemento HTML de um select
     **/
    var _getComboBox = function (el) {
            if (el == null) {
                return null;
            }

            var select1 = el;

            // se for do tipo string
            if (typeof el == "string") {
                // verifica se é vazio
                if (el.trim() == "") {
                    return null;
                }

                select1 = document.getElementById(select1);
            }

            if (select1 == null) {
                return null;
            }

            return select1;
        };



    return {
        /**
         * @descrição: Adiciona um item em um objeto do tipo SELECT (ComboBox)
         *             Recebe como parametro um objeto de configuração, que pode conter os seguintes atributos:
         *             # el: string representando o id de um elemento ou o próprio elemento HTML
         *               value: string representando o value do item
         *               text: string representando o text do item
         *               json (opcional): string representando o objeto completo, não só o seu value e text
         *               selected (opcional): boolean representando se o item será ou não selecionado
         *               itens (opcional): array que irá conter um objeto com os atributos: value, text, json (opcional), selected (opcional)
         **/
        Add: function (config) {
            if (config == null) {
                tmz.Log({
                    msg: "objeto de configuração não informado",
                    type: "error"
                });
                return;
            }

            var select = config.el;

            // se o TERCEIRO arumento não for informado, obtem o obj através do seu ID
            // caso tenha sido informado, utiliza o próprio
            if (typeof select == "string") {
                select = document.getElementById(config.el);
            }

            if (select == null) {
                tmz.Log({
                    msg: "Select " + config.el + " não encontrado",
                    type: "error"
                });
                return;
            }


            // cria um array para os itens que serão adicionados ao combobox
            var arrItens = Array();

            // verifica se o segundo parâmetro foi informado. É esperado um array de itens no segundo Este segundo parâmetro 
            if (config.itens != null) {
                arrItens = config.itens;
            } else {
                // se não existir o parâmetro itens, adiciona um objeto no array
                arrItens.push({
                    value: config.value,
                    text: config.text,
                    json: config.json,
                    selected: config.selected
                });
            }

            for (var i = 0; i < arrItens.length; i++) {
                var obj = arrItens[i];

                select.options[select.length] = new Option(obj.text, obj.value);

                if ((obj.json != null) && (obj.json != "")) {
                    select.options[select.length - 1].setAttribute("json", obj.json);
                }

                if ((obj.selected != null) && (obj.selected)) {
                    select.options[select.length - 1].selected = true;
                    select.options[select.length - 1].setAttribute("selected", true);
                } else {
                    select.options[select.length - 1].removeAttribute("selected");
                }
            }
        },

        /**
         *
         **/
        AddOption: function (config) {
            if (config == null) {
                tmz.Log({
                    msg: "objeto de configuração não informado",
                    type: "error"
                });
                return;
            }

            var select = config.el;

            // se o TERCEIRO arumento não for informado, obtem o obj através do seu ID
            // caso tenha sido informado, utiliza o próprio
            if (typeof select == "string") {
                select = document.getElementById(select);
            }

            if (select == null) {
                tmz.Log({
                    msg: "Select " + config.el + " não encontrado",
                    type: "error"
                });
                return;
            }

            var opt = document.createElement('option');
            opt.value = config.value;
            opt.text = config.text;

            try {
                select.add(opt, null);
            } catch (e) {
                select.add(opt);
            } // IE
            if ((config.selected != null) && (config.selected)) {
                opt.selected = true;
            }
        },


        /**
         * @descrição: Obtém o value, text e o atributo json do item selecionado no combobox
         * @return: Object com três atributos: value, text e json
         **/
        Get: function (el) {
            var select = _getComboBox(el); /* el;*/

            if (select == null) {
                return;
            }

            var text = "",
                value = "",
                json = null;

            // obtém o text do item selecionado
            if (select.selectedIndex >= 0) {
                text = select.options[select.selectedIndex].text;
            }

            // obtém o value e o json do item selecionado
            if (select.length >= 1) {
                if (select.selectedIndex >= 0) {
                    value = select.options[select.selectedIndex].value;
                    json = select.options[select.selectedIndex].getAttribute("json");

                    // verifica se existe a função
                    if (JSON.parse != null) {
                        // faz um PARSE na string
                        json = JSON.parse(json);
                    }
                }
            }

            var itemSelected = true;

            // se o value for VAZIO, significa que nenhum item foi selecionado
            if (value == "") {
                itemSelected = false;
            }

            // obtém  o atributo valuedefault e transforma em objeto
            var attrDefault = select.getAttribute("valuedefault"),
                objDefault = null;

            if (attrDefault != null) {
                objDefault = JSON.parse(attrDefault);

                // se o value selecionado for igual ao value do attrDefault, significa que nenhum item foi selecionado
                if (objDefault.value == value) {
                    itemSelected = false;
                }
            }

            return {
                value: value,
                text: text,
                data: json,
                dataDefault: objDefault,
                itemSelected: itemSelected
            };
        },

        /**
         * @descrição: Deixa o combobox com o item selecionado
         * @params: el: pode ser uma string representando o ID do elemento ou então o próprio elemento HTML
         * @params: valor: será selecionado o item onde o seu value seja igual a este atributo ‘valor’
         * @return: object: Parâmetro com os seguintes atributos: value e text, representando o elemento selecionado
         **/
        SelecionarIndexPeloValue: function (el, valor) {
            var select = (typeof el == "string") ? ((el != "") ? document.getElementById(el) : null) : el,
                valor = (typeof valor == "number") ? valor : valor.toLowerCase(),
                valorComboBox = "",
                o = null;

            // marca o option como selected caso o seu value seja igual
            for (var i = 0; i < select.children.length; i++) {
                valorComboBox = (typeof valor == "number") ? parseInt(((select.children[i].value == "") ? 0 : select.children[i].value), 10) : select.children[i].value.toLowerCase();

                if (valorComboBox == valor) {
                    // deixa o item selecionado
                    select.children[i].selected = true;

                    if (o == null) {
                        o = new Object();
                    }

                    o.value = valorComboBox;
                    o.text = select.children[i].text;

                    // verifica se existe o objeto tmz.Theme
                    // se existir, aplica as alterações de interface deste theme
                    //if (tmz.Theme != null) {
                    //tmz.Theme[tmz.settings.theme].ComboBox.Select(select, o);
                    //}
/*if (tmz.Creator.ButtonsForComboBox != null) {
                        if (buttonsForComboBoxLocate != null) {
                            // vai obter as configurações de botões do combobox
                            var indiceCfg1 = buttonsForComboBoxLocate(select.id);
                            if (indiceCfg1 >= 0) {
                                var cfgButton1 = tmz._buttonsForComboBox[indiceCfg1].cfg;
                                tmz.Creator.ButtonsForComboBox.ChangeStateButtons(cfgButton1, true); // false => desabilita os botões
                            }
                        }
                    }*/


                    return o;
                } else {
                    // desmarca o item
                    select.children[i].selected = false;
                }
            }

            return o;
        }
    };

}();